#include "klistwidget.h"

#include <QPropertyAnimation>
#include <QDateTime>
#include <QTimer>
#include <QDebug>

KListWidget::KListWidget(QWidget *parent) :
    QListWidget(parent),
    m_lastAddTime(0)
{
}

KListWidget::~KListWidget()
{

}

void KListWidget::setItemWidget(QListWidgetItem *item, QWidget *widget)
{
    QWidget *itemW = new QWidget;
    QSize itemSize = item->sizeHint();
    widget->setParent(itemW);
    widget->resize(itemSize);
    itemW->show();
    return;
    widget->move(-itemSize.width(), 0);

    // 渐入动画效果
    QPropertyAnimation *anm = new QPropertyAnimation(this);
    anm->setTargetObject(widget);
    anm->setStartValue(0);
    anm->setEndValue(itemSize.width());
    anm->setDuration(m_setWidgetDuration);
    anm->setEasingCurve(QEasingCurve::OutCubic);
    anm->setObjectName("s");
    connect(anm, &QPropertyAnimation::valueChanged, [this, widget, itemSize, anm](QVariant val){
        if (widget)
            widget->move(val.toInt() - itemSize.width(), 0);

        if (anm->objectName() == "s") {
            if (val.toDouble() / anm->endValue().toDouble() < 0.3) {
                anm->setObjectName("e");
                QTimer::singleShot(200, [this](){
                    m_removeAnm_queue.pop_front();
                    if (!m_removeAnm_queue.isEmpty()) {
                        m_removeAnm_queue.front()->start();
                        qDebug() << "start next anm!";
                    }
                });
            }
        }

    });
    connect(anm, &QPropertyAnimation::finished, [this, anm]{
        anm->deleteLater();
    });
    if (m_removeAnm_queue.isEmpty())
        anm->start();
    m_removeAnm_queue.push_back(anm);

    return QListWidget::setItemWidget(item, itemW);
}

void KListWidget::removeItem(QListWidgetItem *item)
{
    // item 和 itemWidget 全部删除
    QWidget *itemW = itemWidget(item);
    foreach (auto c, itemW->children()) {
        if (c) {
            // 删除动画
            QSize itemSize = item->sizeHint();
            QPropertyAnimation *anm = new QPropertyAnimation(this);
            anm->setTargetObject(c);
            anm->setStartValue(0);
            anm->setEndValue(itemSize.width());
            anm->setDuration(m_removeWidgetDuration);
            anm->setEasingCurve(QEasingCurve::OutCubic);
            connect(anm, &QPropertyAnimation::valueChanged, [this, c, itemSize](QVariant val){
                if (c)
                    static_cast<QWidget*> (c)->move(-val.toInt()-5, 0);
            });
            connect(anm, &QPropertyAnimation::finished, [this, anm, c, itemW, item]{
                QPropertyAnimation *anml = new QPropertyAnimation;
                anml->setTargetObject(this);
                anml->setStartValue(item->sizeHint().height());
                anml->setEndValue(0);
                anml->setDuration(m_removeWidgetDuration);
                anml->setEasingCurve(QEasingCurve::OutCubic);
                anml->setObjectName("s");
                connect(anml, &QPropertyAnimation::valueChanged, [this, item, anml](QVariant val){
                    item->setSizeHint(QSize(item->sizeHint().width(), val.toInt()));
                    if (anml->objectName() == "s") {
                        if (val.toDouble() / anml->startValue().toDouble() < 0.9) {
                            anml->setObjectName("e");
                            m_setAnm_queue.pop_front();
                            if (!m_setAnm_queue.isEmpty()) {
                                m_setAnm_queue.front()->start();
                                qDebug() << "start next anm!";
                            }
                        }
                    }
                });

                connect(anml, &QPropertyAnimation::finished, [this, c, itemW, item, anm, anml]{
                    QListWidget::removeItemWidget(item);
                    delete c;
                    delete itemW;

                    takeItem(this->row(item));
                    delete item;

                    anml->deleteLater();
                    anm->deleteLater();

                });
                anml->start();
            });
            if (m_setAnm_queue.isEmpty())
                anm->start();
            m_setAnm_queue.push_back(anm);
        }
    }
}
