#include <QApplication>
#include <QDBusConnection>
#include <QDBusInterface>
#include <QDBusReply>
#include <QFileInfo>
#include <QScreen>
#include <QDebug>

#include <ukui-log4qt.h>

#include "mainwidget.h"
#include "global/global.h"
#include "global/paths.h"
#include "global/functions.h"

#include <syslog.h>
#include <fcntl.h>
#include <unistd.h>

using namespace Global;

int main(int argc, char **argv)
{
    initUkuiLog4qt("kylin-video");

    if(QString(qgetenv("XDG_SESSION_TYPE")) == "wayland") {
        qputenv("QT_QPA_PLATFORM", "wayland");
    }
    else {
#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0))
    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
#endif
    }

    QApplication a(argc, argv);

    a.setWindowIcon(QIcon::fromTheme("kylin-video"));

    Global::global_init();

    QFile qss(":/qss/style.qss");
    if (!qss.open(QIODevice::ReadOnly)) {
        qWarning("Can't open the style sheet file: :/qss/res/style.qss.");
    }
    else {
        qApp->setStyleSheet(qss.readAll());
        qss.close();
    }

    QStringList arg_list;
    for(int i=1; i<argc; i++)
    {
        QFileInfo f(QString(argv[i]));
        if(f.isFile())
            arg_list << f.absoluteFilePath();
    }

    MainWidget w(arg_list);
    w.show();

    return a.exec();
}
